AsValue

Trait AsValue 

pub trait AsValue {
    type Output: Borrow<Value>;

    // Required method
    fn as_value(self) -> Self::Output;
}
A trait for types that can be converted into a Value or allow accessing it as a reference.

Required Associated Types

type Output: Borrow<Value>

The type of the value. It needs to be able to be borrowed as a Value.

Required Methods

fn as_value(self) -> Self::Output

Converts the value into a type that can be borrowed as a Value.

Implementors

Source

impl<'a> AsValue for &'a Value

Source

impl<T> AsValue for T
where Value: From<T>,